@@ -85,6 +85,17 @@ my $prebuilt_binaries = [
       cc_re    => qr/gcc/,
       gccversion_re => qr/^4\.(4\.[5-9]|[5-9]\.[0-9])$/,
     },
+    {
+      title    => "Binaries Win/32bit SDL-1.2.15 (20120610)\n" .
+                  "\t(gfx, image, mixer, smpeg, ttf)",
+      url      => [
+        'http://froggs.de/libsdl/Win32_SDL-1.2.15-20120610.zip',
+      ],
+      sha1sum  => 'fb0a582845b557a189700286eb57ce63f56a179c',
+      arch_re  => qr/^MSWin32/,
+      os_re    => qr/^MSWin32$/,
+      cc_re    => qr/cl/,
+    },
  ];
 
 #### tarballs with source codes
@@ -174,6 +185,7 @@ our $source_packs = [
         sha1sum  => 'ec9841377403e8d1bcfd76626434be64d11f59f0',
         patches => [
           'test1.patch',
+          'SDL-1.2-openbsd-rldflags.patch',
         ],
         prereqs => {
           libs => [
@@ -412,7 +424,6 @@ sub check_prereqs_tools {
       $ret &= 1;
     }
     else {
-      print "WARNING: required '$tool' not found\n";
       $ret = 0;
     }
   }
